/* Stata program to read in the Cameron and Tridevi data set */

/* The data set racd3.asc cotains data used in Chapter 3 of

Cameron AC, Trivedi PK. 1998.  Regression Analysis of Count Data. 
Cambridge University Press: Cambridge

This data is not a representative sample of Australians as it oversamples
young and old. In particular, use of health services may be overstated.

This is because while the original sample of 40,650 individuals 
from the A.B.S. 1977-78 Australian Health Survey is representative, 
the sample used here is restricted to single people over 18 years of age.

See: 

A.C. Cameron, P.K. Trivedi, F. Milne and J. Piggott (1988), 
"A Microeconometric Model of the Demand for Health Care and Health
Insurance in Australia", Review of Economic Studies, Vol.55, pp. 85-106.

for more detailed discussion of the data than that given in the 1998 book.

Additional information about these data can be found at 

http://www.econ.ucdavis.edu/faculty/cameron/racd/racd3.1st (accessed August 3, 2010)


These data are space delimited and can be read using Stata with the command 

infile 
sex  age  agesq  income  levyplus  freepoor  freerepa  
illness  actdays  hscore  chcond1  chcond2  
doctorco  nondocco  hospadmi  hospdays  medicine  prescrib  nonpresc  constant

using racd3.asc ;  /* this file's size is approximately 416Kb */ 


The file  Read_Cameron_Trivedi_data.do  reads in the data and estimaters a simple 
Poisson model of the number of doctor visits.


Summary statistics for this data set: 


. summarize ;

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
         sex |      5190    .5206166    .4996229          0          1
         age |      5190    .4063854    .2047818        .19        .72
       agesq |      5190    .2070766    .1856365      .0361      .5184
      income |      5190    .5831599    .3689067          0        1.5
    levyplus |      5190    .4427746    .4967623          0          1
-------------+--------------------------------------------------------
    freepoor |      5190    .0427746     .202368          0          1
    freerepa |      5190    .2102119    .4074983          0          1
     illness |      5190    1.431985    1.384152          0          5
     actdays |      5190    .8618497    2.887628          0         14
      hscore |      5190    1.217534    2.124266          0         12
-------------+--------------------------------------------------------
     chcond1 |      5190    .4030829    .4905644          0          1
     chcond2 |      5190    .1165703    .3209385          0          1
    doctorco |      5190    .3017341    .7981338          0          9
    nondocco |      5190    .2146435    .9652756          0         11
    hospadmi |      5190    .1736031    .5075236          0          5
-------------+--------------------------------------------------------
    hospdays |      5190    1.333719    6.120081          0         80
    medicine |      5190    1.218304    1.556643          0          8
    prescrib |      5190    .8626204    1.415375          0          8
    nonpresc |      5190     .355684     .712389          0          8
    constant |      5190           1           0          1          1

*/


drop _all
set memory 10m

# delimit ;
infile sex  age  agesq  income  levyplus  freepoor  freerepa  
illness  actdays  hscore  chcond1  chcond2  
doctorco  nondocco  hospadmi  hospdays  medicine  prescrib  nonpresc  constant

using racd3.asc ;

summarize ;

poisson doctorco
sex  age  agesq  income  levyplus  freepoor  freerepa  
illness  actdays  hscore  chcond1  chcond2 
;


